/* A Bison parser, made by GNU Bison 1.875.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Written by Richard Stallman by simplifying the original so called
   ``semantic'' parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 1

/* Using locations.  */
#define YYLSP_NEEDED 0

/* If NAME_PREFIX is specified substitute the variables and functions
   names.  */
#define yyparse _dxfccparse
#define yylex   _dxfcclex
#define yyerror _dxfccerror
#define yylval  _dxfcclval
#define yychar  _dxfccchar
#define yydebug _dxfccdebug
#define yynerrs _dxfccnerrs


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     T_NAME = 258,
     T_FLOAT = 259,
     T_DOUBLE = 260,
     T_INT = 261,
     T_INPUT = 262,
     T_ID = 263,
     T_STRING = 264,
     T_EOF = 265,
     T_LPAR = 266,
     T_RPAR = 267,
     T_LBRA = 268,
     T_RBRA = 269,
     T_LSQB = 270,
     T_RSQB = 271,
     T_COMMA = 272,
     T_PERIOD = 273,
     T_COLON = 274,
     T_LOR = 275,
     T_LAND = 276,
     T_LNOT = 277,
     T_LT = 278,
     T_LE = 279,
     T_GT = 280,
     T_GE = 281,
     T_EQ = 282,
     T_NE = 283,
     T_QUEST = 284,
     T_CROSS = 285,
     T_DOT = 286,
     T_PLUS = 287,
     T_MINUS = 288,
     T_EXP = 289,
     T_TIMES = 290,
     T_DIV = 291,
     T_MOD = 292,
     T_ASSIGN = 293,
     T_SEMI = 294,
     U_PLUS = 295,
     U_MINUS = 296,
     U_LNOT = 297
   };
#endif
#define T_NAME 258
#define T_FLOAT 259
#define T_DOUBLE 260
#define T_INT 261
#define T_INPUT 262
#define T_ID 263
#define T_STRING 264
#define T_EOF 265
#define T_LPAR 266
#define T_RPAR 267
#define T_LBRA 268
#define T_RBRA 269
#define T_LSQB 270
#define T_RSQB 271
#define T_COMMA 272
#define T_PERIOD 273
#define T_COLON 274
#define T_LOR 275
#define T_LAND 276
#define T_LNOT 277
#define T_LT 278
#define T_LE 279
#define T_GT 280
#define T_GE 281
#define T_EQ 282
#define T_NE 283
#define T_QUEST 284
#define T_CROSS 285
#define T_DOT 286
#define T_PLUS 287
#define T_MINUS 288
#define T_EXP 289
#define T_TIMES 290
#define T_DIV 291
#define T_MOD 292
#define T_ASSIGN 293
#define T_SEMI 294
#define U_PLUS 295
#define U_MINUS 296
#define U_LNOT 297




/* Copy the first part of user declarations.  */
#line 10 "./_compparse.y"

#include <math.h>
#include <string.h>
#include <dx/dx.h>
#include "_compute.h"
#include "_compputils.h"
#include "_compoper.h"


int _dxdparseError = 0;		/* Only shared with _compputils.c */
PTreeNode * _dxfMakeFunCall(char *func, PTreeNode *args);




/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 27 "./_compparse.y"
typedef union YYSTYPE {
#define MAX_PARSE_STRING_SIZE 512
    char s[MAX_PARSE_STRING_SIZE];
    int i;
    float f;
    double d;
    PTreeNode *a;
} YYSTYPE;
/* Line 191 of yacc.c.  */
#line 192 "y.tab.c"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



/* Copy the second part of user declarations.  */


/* Line 214 of yacc.c.  */
#line 204 "y.tab.c"

#if ! defined (yyoverflow) || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# if YYSTACK_USE_ALLOCA
#  define YYSTACK_ALLOC alloca
# else
#  ifndef YYSTACK_USE_ALLOCA
#   if defined (alloca) || defined (_ALLOCA_H)
#    define YYSTACK_ALLOC alloca
#   else
#    ifdef __GNUC__
#     define YYSTACK_ALLOC __builtin_alloca
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning. */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
# else
#  if defined (__STDC__) || defined (__cplusplus)
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   define YYSIZE_T size_t
#  endif
#  define YYSTACK_ALLOC malloc
#  define YYSTACK_FREE free
# endif
#endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */


#if (! defined (yyoverflow) \
     && (! defined (__cplusplus) \
	 || (YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  short yyss;
  YYSTYPE yyvs;
  };

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  register YYSIZE_T yyi;		\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];		\
	}					\
      while (0)
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack)					\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack, Stack, yysize);				\
	Stack = &yyptr->Stack;						\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (0)

#endif

#if defined (__STDC__) || defined (__cplusplus)
   typedef signed char yysigned_char;
#else
   typedef short yysigned_char;
#endif

/* YYFINAL -- State number of the termination state. */
#define YYFINAL  3
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   265

/* YYNTOKENS -- Number of terminals. */
#define YYNTOKENS  43
/* YYNNTS -- Number of nonterminals. */
#define YYNNTS  10
/* YYNRULES -- Number of rules. */
#define YYNRULES  50
/* YYNRULES -- Number of states. */
#define YYNSTATES  94

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   297

#define YYTRANSLATE(YYX) 						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const unsigned char yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const unsigned char yyprhs[] =
{
       0,     0,     3,     4,     8,    10,    13,    17,    20,    22,
      26,    30,    32,    36,    40,    45,    50,    55,    60,    66,
      70,    74,    78,    82,    86,    90,    94,    98,   102,   106,
     110,   114,   118,   122,   126,   130,   133,   136,   139,   143,
     145,   146,   148,   150,   154,   156,   160,   162,   164,   166,
     168
};

/* YYRHS -- A `-1'-separated list of the rules' RHS. */
static const yysigned_char yyrhs[] =
{
      44,     0,    -1,    -1,    45,    46,    10,    -1,    47,    -1,
      39,    46,    -1,    46,    39,    47,    -1,    46,    39,    -1,
       7,    -1,    47,    18,    51,    -1,    47,    18,     3,    -1,
      51,    -1,    11,    47,    12,    -1,    15,    50,    16,    -1,
       3,    11,    48,    12,    -1,    37,    11,    48,    12,    -1,
      31,    11,    48,    12,    -1,    30,    11,    48,    12,    -1,
      47,    29,    47,    19,    47,    -1,    47,    21,    47,    -1,
      47,    20,    47,    -1,    47,    25,    47,    -1,    47,    26,
      47,    -1,    47,    23,    47,    -1,    47,    24,    47,    -1,
      47,    27,    47,    -1,    47,    28,    47,    -1,    47,    32,
      47,    -1,    47,    33,    47,    -1,    47,    35,    47,    -1,
      47,    36,    47,    -1,    47,    37,    47,    -1,    47,    31,
      47,    -1,    47,    30,    47,    -1,    47,    34,    47,    -1,
      33,    47,    -1,    32,    47,    -1,    22,    47,    -1,     3,
      38,    47,    -1,     3,    -1,    -1,    49,    -1,    47,    -1,
      49,    17,    47,    -1,    47,    -1,    50,    17,    47,    -1,
      52,    -1,     6,    -1,     4,    -1,     5,    -1,     9,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const unsigned short yyrline[] =
{
       0,   118,   118,   118,   136,   140,   144,   152,   163,   167,
     171,   195,   196,   200,   204,   222,   231,   240,   249,   253,
     257,   261,   265,   269,   273,   277,   281,   285,   289,   293,
     297,   301,   305,   309,   313,   317,   321,   325,   329,   333,
     341,   344,   348,   352,   364,   368,   387,   391,   399,   407,
     415
};
#endif

#if YYDEBUG || YYERROR_VERBOSE
/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals. */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "T_NAME", "T_FLOAT", "T_DOUBLE", "T_INT", 
  "T_INPUT", "T_ID", "T_STRING", "T_EOF", "T_LPAR", "T_RPAR", "T_LBRA", 
  "T_RBRA", "T_LSQB", "T_RSQB", "T_COMMA", "T_PERIOD", "T_COLON", "T_LOR", 
  "T_LAND", "T_LNOT", "T_LT", "T_LE", "T_GT", "T_GE", "T_EQ", "T_NE", 
  "T_QUEST", "T_CROSS", "T_DOT", "T_PLUS", "T_MINUS", "T_EXP", "T_TIMES", 
  "T_DIV", "T_MOD", "T_ASSIGN", "T_SEMI", "U_PLUS", "U_MINUS", "U_LNOT", 
  "$accept", "top", "@1", "statement_list", "expr", 
  "optional_argument_list", "argument_list", "list", "constant", "real", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const unsigned short yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const unsigned char yyr1[] =
{
       0,    43,    45,    44,    46,    46,    46,    46,    47,    47,
      47,    47,    47,    47,    47,    47,    47,    47,    47,    47,
      47,    47,    47,    47,    47,    47,    47,    47,    47,    47,
      47,    47,    47,    47,    47,    47,    47,    47,    47,    47,
      48,    48,    49,    49,    50,    50,    51,    52,    52,    52,
      52
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const unsigned char yyr2[] =
{
       0,     2,     0,     3,     1,     2,     3,     2,     1,     3,
       3,     1,     3,     3,     4,     4,     4,     4,     5,     3,
       3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     3,     3,     2,     2,     2,     3,     1,
       0,     1,     1,     3,     1,     3,     1,     1,     1,     1,
       1
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const unsigned char yydefact[] =
{
       2,     0,     0,     1,    39,    48,    49,    47,     8,    50,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       4,    11,    46,    40,     0,     0,    44,     0,    37,    40,
      40,    36,    35,    40,     5,     3,     7,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,    42,     0,    41,    38,    12,
      13,     0,     0,     0,     0,     6,    10,     9,    20,    19,
      23,    24,    21,    22,    25,    26,     0,    33,    32,    27,
      28,    34,    29,    30,    31,    14,     0,    45,    17,    16,
      15,     0,    43,    18
};

/* YYDEFGOTO[NTERM-NUM]. */
static const yysigned_char yydefgoto[] =
{
      -1,     1,     2,    19,    55,    56,    57,    27,    21,    22
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -34
static const short yypact[] =
{
     -34,     3,    60,   -34,    -7,   -34,   -34,   -34,   -34,   -34,
      97,    97,    97,     6,    16,    97,    97,    22,    60,    -9,
     159,   -34,   -34,    97,    97,   119,   159,    -5,   -34,    97,
      97,   -34,   -34,    97,   -33,   -34,    97,    52,    97,    97,
      97,    97,    97,    97,    97,    97,    97,    97,    97,    97,
      97,    97,    97,    97,    97,   159,    23,    36,   159,   -34,
     -34,    97,    50,    56,    58,   159,   -34,   -34,   179,   199,
     228,   228,   228,   228,   219,   219,   139,    42,   -13,   -11,
     -11,    54,   -16,   -16,   -16,   -34,    97,   159,   -34,   -34,
     -34,    97,   159,   159
};

/* YYPGOTO[NTERM-NUM].  */
static const yysigned_char yypgoto[] =
{
     -34,   -34,   -34,    62,    -2,    -1,   -34,   -34,    17,   -34
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -1
static const unsigned char yytable[] =
{
      20,    35,    37,     3,    23,    37,    36,    37,    25,    26,
      28,    60,    61,    31,    32,    48,    20,    29,    51,    47,
      48,    51,    58,    51,    52,    53,    54,    30,    62,    63,
      36,    24,    64,    33,    65,    85,    68,    69,    70,    71,
      72,    73,    74,    75,    76,    77,    78,    79,    80,    81,
      82,    83,    84,    86,    67,    66,     5,     6,     7,    87,
      37,     9,    88,     4,     5,     6,     7,     8,    89,     9,
      90,    10,    37,    48,     0,    11,    51,    52,    53,    54,
      34,     0,    12,     0,    92,     0,     0,     0,     0,    93,
      13,    14,    15,    16,     0,     0,     0,    17,     0,    18,
       4,     5,     6,     7,     8,     0,     9,     0,    10,     0,
       0,     0,    11,     0,     0,     0,     0,     0,     0,    12,
       0,     0,     0,     0,     0,     0,     0,    13,    14,    15,
      16,    59,     0,     0,    17,     0,     0,    37,     0,    38,
      39,     0,    40,    41,    42,    43,    44,    45,    46,    47,
      48,    49,    50,    51,    52,    53,    54,    37,    91,    38,
      39,     0,    40,    41,    42,    43,    44,    45,    46,    47,
      48,    49,    50,    51,    52,    53,    54,    37,     0,    38,
      39,     0,    40,    41,    42,    43,    44,    45,    46,    47,
      48,    49,    50,    51,    52,    53,    54,    37,     0,     0,
      39,     0,    40,    41,    42,    43,    44,    45,     0,    47,
      48,    49,    50,    51,    52,    53,    54,    37,     0,     0,
       0,     0,    40,    41,    42,    43,    44,    45,     0,    47,
      48,    49,    50,    51,    52,    53,    54,    37,     0,     0,
       0,     0,    40,    41,    42,    43,    37,     0,     0,    47,
      48,    49,    50,    51,    52,    53,    54,     0,    47,    48,
      49,    50,    51,    52,    53,    54
};

static const yysigned_char yycheck[] =
{
       2,    10,    18,     0,    11,    18,    39,    18,    10,    11,
      12,    16,    17,    15,    16,    31,    18,    11,    34,    30,
      31,    34,    24,    34,    35,    36,    37,    11,    29,    30,
      39,    38,    33,    11,    36,    12,    38,    39,    40,    41,
      42,    43,    44,    45,    46,    47,    48,    49,    50,    51,
      52,    53,    54,    17,    37,     3,     4,     5,     6,    61,
      18,     9,    12,     3,     4,     5,     6,     7,    12,     9,
      12,    11,    18,    31,    -1,    15,    34,    35,    36,    37,
      18,    -1,    22,    -1,    86,    -1,    -1,    -1,    -1,    91,
      30,    31,    32,    33,    -1,    -1,    -1,    37,    -1,    39,
       3,     4,     5,     6,     7,    -1,     9,    -1,    11,    -1,
      -1,    -1,    15,    -1,    -1,    -1,    -1,    -1,    -1,    22,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    30,    31,    32,
      33,    12,    -1,    -1,    37,    -1,    -1,    18,    -1,    20,
      21,    -1,    23,    24,    25,    26,    27,    28,    29,    30,
      31,    32,    33,    34,    35,    36,    37,    18,    19,    20,
      21,    -1,    23,    24,    25,    26,    27,    28,    29,    30,
      31,    32,    33,    34,    35,    36,    37,    18,    -1,    20,
      21,    -1,    23,    24,    25,    26,    27,    28,    29,    30,
      31,    32,    33,    34,    35,    36,    37,    18,    -1,    -1,
      21,    -1,    23,    24,    25,    26,    27,    28,    -1,    30,
      31,    32,    33,    34,    35,    36,    37,    18,    -1,    -1,
      -1,    -1,    23,    24,    25,    26,    27,    28,    -1,    30,
      31,    32,    33,    34,    35,    36,    37,    18,    -1,    -1,
      -1,    -1,    23,    24,    25,    26,    18,    -1,    -1,    30,
      31,    32,    33,    34,    35,    36,    37,    -1,    30,    31,
      32,    33,    34,    35,    36,    37
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const unsigned char yystos[] =
{
       0,    44,    45,     0,     3,     4,     5,     6,     7,     9,
      11,    15,    22,    30,    31,    32,    33,    37,    39,    46,
      47,    51,    52,    11,    38,    47,    47,    50,    47,    11,
      11,    47,    47,    11,    46,    10,    39,    18,    20,    21,
      23,    24,    25,    26,    27,    28,    29,    30,    31,    32,
      33,    34,    35,    36,    37,    47,    48,    49,    47,    12,
      16,    17,    48,    48,    48,    47,     3,    51,    47,    47,
      47,    47,    47,    47,    47,    47,    47,    47,    47,    47,
      47,    47,    47,    47,    47,    12,    17,    47,    12,    12,
      12,    19,    47,    47
};

#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
# define YYSIZE_T __SIZE_TYPE__
#endif
#if ! defined (YYSIZE_T) && defined (size_t)
# define YYSIZE_T size_t
#endif
#if ! defined (YYSIZE_T)
# if defined (__STDC__) || defined (__cplusplus)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# endif
#endif
#if ! defined (YYSIZE_T)
# define YYSIZE_T unsigned int
#endif

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrlab1

/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto yyerrlab

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      yytoken = YYTRANSLATE (yychar);				\
      YYPOPSTACK;						\
      goto yybackup;						\
    }								\
  else								\
    { 								\
      yyerror ("syntax error: cannot back up");\
      YYERROR;							\
    }								\
while (0)

#define YYTERROR	1
#define YYERRCODE	256

/* YYLLOC_DEFAULT -- Compute the default location (before the actions
   are run).  */

#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)         \
  Current.first_line   = Rhs[1].first_line;      \
  Current.first_column = Rhs[1].first_column;    \
  Current.last_line    = Rhs[N].last_line;       \
  Current.last_column  = Rhs[N].last_column;
#endif

/* YYLEX -- calling `yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX yylex (&yylval, YYLEX_PARAM)
#else
# define YYLEX yylex (&yylval)
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (0)

# define YYDSYMPRINT(Args)			\
do {						\
  if (yydebug)					\
    yysymprint Args;				\
} while (0)

# define YYDSYMPRINTF(Title, Token, Value, Location)		\
do {								\
  if (yydebug)							\
    {								\
      YYFPRINTF (stderr, "%s ", Title);				\
      yysymprint (stderr, 					\
                  Token, Value);	\
      YYFPRINTF (stderr, "\n");					\
    }								\
} while (0)

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (cinluded).                                                   |
`------------------------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_stack_print (short *bottom, short *top)
#else
static void
yy_stack_print (bottom, top)
    short *bottom;
    short *top;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (/* Nothing. */; bottom <= top; ++bottom)
    YYFPRINTF (stderr, " %d", *bottom);
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_reduce_print (int yyrule)
#else
static void
yy_reduce_print (yyrule)
    int yyrule;
#endif
{
  int yyi;
  unsigned int yylineno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
             yyrule - 1, yylineno);
  /* Print the symbols being reduced, and their result.  */
  for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
    YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[yyrule]]);
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (Rule);		\
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YYDSYMPRINT(Args)
# define YYDSYMPRINTF(Title, Token, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#if YYMAXDEPTH == 0
# undef YYMAXDEPTH
#endif

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined (__GLIBC__) && defined (_STRING_H)
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
#   if defined (__STDC__) || defined (__cplusplus)
yystrlen (const char *yystr)
#   else
yystrlen (yystr)
     const char *yystr;
#   endif
{
  register const char *yys = yystr;

  while (*yys++ != '\0')
    continue;

  return yys - yystr - 1;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined (__GLIBC__) && defined (_STRING_H) && defined (_GNU_SOURCE)
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
#   if defined (__STDC__) || defined (__cplusplus)
yystpcpy (char *yydest, const char *yysrc)
#   else
yystpcpy (yydest, yysrc)
     char *yydest;
     const char *yysrc;
#   endif
{
  register char *yyd = yydest;
  register const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

#endif /* !YYERROR_VERBOSE */



#if YYDEBUG
/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yysymprint (FILE *yyoutput, int yytype, YYSTYPE *yyvaluep)
#else
static void
yysymprint (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  if (yytype < YYNTOKENS)
    {
      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
# ifdef YYPRINT
      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
    }
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  switch (yytype)
    {
      default:
        break;
    }
  YYFPRINTF (yyoutput, ")");
}

#endif /* ! YYDEBUG */
/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yydestruct (int yytype, YYSTYPE *yyvaluep)
#else
static void
yydestruct (yytype, yyvaluep)
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  switch (yytype)
    {

      default:
        break;
    }
}


/* Prevent warnings from -Wmissing-prototypes.  */

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM);
# else
int yyparse ();
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int yyparse (void);
#else
int yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */






/*----------.
| yyparse.  |
`----------*/

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM)
# else
int yyparse (YYPARSE_PARAM)
  void *YYPARSE_PARAM;
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int
yyparse (void)
#else
int
yyparse ()

#endif
#endif
{
  /* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;

/* Number of syntax errors so far.  */
int yynerrs;

  register int yystate;
  register int yyn;
  int yyresult;
  /* Number of tokens to shift before error messages enabled.  */
  int yyerrstatus;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;

  /* Three stacks and their tools:
     `yyss': related to states,
     `yyvs': related to semantic values,
     `yyls': related to locations.

     Refer to the stacks thru separate pointers, to allow yyoverflow
     to reallocate them elsewhere.  */

  /* The state stack.  */
  short	yyssa[YYINITDEPTH];
  short *yyss = yyssa;
  register short *yyssp;

  /* The semantic value stack.  */
  YYSTYPE yyvsa[YYINITDEPTH];
  YYSTYPE *yyvs = yyvsa;
  register YYSTYPE *yyvsp;



#define YYPOPSTACK   (yyvsp--, yyssp--)

  YYSIZE_T yystacksize = YYINITDEPTH;

  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;


  /* When reducing, the number of symbols on the RHS of the reduced
     rule.  */
  int yylen;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss;
  yyvsp = yyvs;

  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed. so pushing a state here evens the stacks.
     */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack. Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	short *yyss1 = yyss;


	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow ("parser stack overflow",
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),

		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyoverflowlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyoverflowlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	short *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyoverflowlab;
	YYSTACK_RELOCATE (yyss);
	YYSTACK_RELOCATE (yyvs);

#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;


      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

/* Do appropriate processing given the current state.  */
/* Read a lookahead token if we need one and don't already have one.  */
/* yyresume: */

  /* First try to decide what to do without reference to lookahead token.  */

  yyn = yypact[yystate];
  if (yyn == YYPACT_NINF)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yyn == 0 || yyn == YYTABLE_NINF)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Shift the lookahead token.  */
  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));

  /* Discard the token being shifted unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  *++yyvsp = yylval;


  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  yystate = yyn;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 2:
#line 118 "./_compparse.y"
    { _dxdparseError = 0; }
    break;

  case 3:
#line 120 "./_compparse.y"
    {
	    if (_dxdparseError)
	    {
		if (yyvsp[-1].a) {
		    _dxfComputeFreeTree(yyvsp[-1].a);
		}
		_dxdcomputeTree = NULL;
		YYABORT;
	    }

	    _dxdcomputeTree = _dxfMakeList(NT_TOP, yyvsp[-1].a);
	    YYACCEPT;
	}
    break;

  case 4:
#line 137 "./_compparse.y"
    {
	    yyval.a->next = NULL;
	}
    break;

  case 5:
#line 141 "./_compparse.y"
    {
	    yyval.a = yyvsp[0].a;
	}
    break;

  case 6:
#line 145 "./_compparse.y"
    {
	    PTreeNode *t = yyvsp[-2].a;
	    while (t->next != NULL)
		t = t->next;
	    t->next = yyvsp[0].a;
	    yyval.a = yyvsp[-2].a;
	}
    break;

  case 7:
#line 153 "./_compparse.y"
    {
	    PTreeNode *t = yyvsp[-1].a;
	    while (t->next != NULL)
		t = t->next;
	    t->next = NULL;
	    yyval.a = yyvsp[-1].a;
	}
    break;

  case 8:
#line 164 "./_compparse.y"
    {
	    yyval.a = _dxfMakeInput(yyvsp[0].i);
	}
    break;

  case 9:
#line 168 "./_compparse.y"
    {
	    yyval.a = _dxfMakeBinOp(OPER_PERIOD, yyvsp[-2].a, yyvsp[0].a);
	}
    break;

  case 10:
#line 172 "./_compparse.y"
    {
	    PTreeNode *pt;
	    pt = _dxfMakeArg(NT_CONSTANT);
	    pt->metaType.items = 1;
	    pt->metaType.type = TYPE_INT;
	    pt->metaType.category = CATEGORY_REAL;
	    if (strcmp (yyvsp[0].s, "x") == 0) {
		pt->u.i = 0;
	    }
	    else if (strcmp (yyvsp[0].s, "y") == 0) {
		pt->u.i = 1;
	    }
	    else if (strcmp (yyvsp[0].s, "z") == 0) {
		pt->u.i = 2;
	    }
	    else {
		DXSetError(ERROR_BAD_PARAMETER, "#12100",
		    "syntax error");
		_dxdparseError++;
		YYERROR;
	    }
	    yyval.a = _dxfMakeBinOp(OPER_PERIOD, yyvsp[-2].a, pt);
	}
    break;

  case 12:
#line 197 "./_compparse.y"
    {
	    yyval.a = yyvsp[-1].a;
	}
    break;

  case 13:
#line 201 "./_compparse.y"
    {
	    yyval.a = _dxfMakeList (NT_CONSTRUCT, yyvsp[-1].a);
	}
    break;

  case 14:
#line 206 "./_compparse.y"
    {
	    /* It must be a function id */
	    if (_dxfComputeLookupFunction (yyvsp[-3].s) == NT_ERROR) {
		DXSetError(ERROR_BAD_PARAMETER, "#12090", yyvsp[-3].s);
		_dxdparseError++;
		YYERROR;
	    }
	    else
	    {
		yyval.a = _dxfMakeFunCall(yyvsp[-3].s, yyvsp[-1].a);
		if (yyval.a == NULL) {
		    _dxdparseError++;
		    YYERROR;
		}
	    }
	}
    break;

  case 15:
#line 224 "./_compparse.y"
    {
	    yyval.a = _dxfMakeFunCall("mod", yyvsp[-1].a);
	    if (yyval.a == NULL) {
		_dxdparseError++;
		YYERROR;
	    }
	}
    break;

  case 16:
#line 233 "./_compparse.y"
    {
	    yyval.a = _dxfMakeFunCall("dot", yyvsp[-1].a);
	    if (yyval.a == NULL) {
		_dxdparseError++;
		YYERROR;
	    }
	}
    break;

  case 17:
#line 242 "./_compparse.y"
    {
	    yyval.a = _dxfMakeFunCall("cross", yyvsp[-1].a);
	    if (yyval.a == NULL) {
		_dxdparseError++;
		YYERROR;
	    }
	}
    break;

  case 18:
#line 250 "./_compparse.y"
    {
            yyval.a = _dxfMakeConditional(yyvsp[-4].a, yyvsp[-2].a, yyvsp[0].a);
        }
    break;

  case 19:
#line 254 "./_compparse.y"
    {
            yyval.a = _dxfMakeBinOp(OPER_AND, yyvsp[-2].a, yyvsp[0].a);
        }
    break;

  case 20:
#line 258 "./_compparse.y"
    {
            yyval.a = _dxfMakeBinOp(OPER_OR, yyvsp[-2].a, yyvsp[0].a);
        }
    break;

  case 21:
#line 262 "./_compparse.y"
    {
            yyval.a = _dxfMakeBinOp(OPER_GT, yyvsp[-2].a, yyvsp[0].a);
        }
    break;

  case 22:
#line 266 "./_compparse.y"
    {
            yyval.a = _dxfMakeBinOp(OPER_GE, yyvsp[-2].a, yyvsp[0].a);
        }
    break;

  case 23:
#line 270 "./_compparse.y"
    {
            yyval.a = _dxfMakeBinOp(OPER_LT, yyvsp[-2].a, yyvsp[0].a);
        }
    break;

  case 24:
#line 274 "./_compparse.y"
    {
            yyval.a = _dxfMakeBinOp(OPER_LE, yyvsp[-2].a, yyvsp[0].a);
        }
    break;

  case 25:
#line 278 "./_compparse.y"
    {
            yyval.a = _dxfMakeBinOp(OPER_EQ, yyvsp[-2].a, yyvsp[0].a);
        }
    break;

  case 26:
#line 282 "./_compparse.y"
    {
            yyval.a = _dxfMakeBinOp(OPER_NE, yyvsp[-2].a, yyvsp[0].a);
        }
    break;

  case 27:
#line 286 "./_compparse.y"
    {
	    yyval.a = _dxfMakeBinOp(OPER_PLUS, yyvsp[-2].a, yyvsp[0].a);
	}
    break;

  case 28:
#line 290 "./_compparse.y"
    {
	    yyval.a = _dxfMakeBinOp(OPER_MINUS, yyvsp[-2].a, yyvsp[0].a);
	}
    break;

  case 29:
#line 294 "./_compparse.y"
    {
	    yyval.a = _dxfMakeBinOp(OPER_MUL, yyvsp[-2].a, yyvsp[0].a);
	}
    break;

  case 30:
#line 298 "./_compparse.y"
    {
	    yyval.a = _dxfMakeBinOp(OPER_DIV, yyvsp[-2].a, yyvsp[0].a);
	}
    break;

  case 31:
#line 302 "./_compparse.y"
    {
	    yyval.a = _dxfMakeBinOp(OPER_MOD, yyvsp[-2].a, yyvsp[0].a);
	}
    break;

  case 32:
#line 306 "./_compparse.y"
    {
	    yyval.a = _dxfMakeBinOp(OPER_DOT, yyvsp[-2].a, yyvsp[0].a);
	}
    break;

  case 33:
#line 310 "./_compparse.y"
    {
	    yyval.a = _dxfMakeBinOp(OPER_CROSS, yyvsp[-2].a, yyvsp[0].a);
	}
    break;

  case 34:
#line 314 "./_compparse.y"
    {
	    yyval.a = _dxfMakeBinOp(OPER_EXP, yyvsp[-2].a, yyvsp[0].a);
	}
    break;

  case 35:
#line 318 "./_compparse.y"
    {
	    yyval.a = _dxfMakeUnOp(OPER_MINUS, yyvsp[0].a);
	}
    break;

  case 36:
#line 322 "./_compparse.y"
    {
	    yyval.a = yyvsp[0].a;
	}
    break;

  case 37:
#line 326 "./_compparse.y"
    {
	    yyval.a = _dxfMakeUnOp (OPER_NOT, yyvsp[0].a);
	}
    break;

  case 38:
#line 330 "./_compparse.y"
    {
	    yyval.a = _dxfMakeAssignment (yyvsp[-2].s, yyvsp[0].a);
	}
    break;

  case 39:
#line 334 "./_compparse.y"
    {
	    yyval.a = _dxfMakeVariable (yyvsp[0].s);
	}
    break;

  case 40:
#line 341 "./_compparse.y"
    {
	    yyval.a = NULL;
	}
    break;

  case 42:
#line 349 "./_compparse.y"
    {
	    yyval.a->next = NULL;
	}
    break;

  case 43:
#line 353 "./_compparse.y"
    {
	    PTreeNode *t = yyvsp[-2].a;
	    while (t->next != NULL)
		t = t->next;
	    t->next = yyvsp[0].a;
	    yyval.a = yyvsp[-2].a;
	}
    break;

  case 44:
#line 365 "./_compparse.y"
    { 
	    yyval.a->next = NULL;
	}
    break;

  case 45:
#line 369 "./_compparse.y"
    {
	    PTreeNode *t = yyvsp[-2].a;
	    while (t->next != NULL)
		t = t->next;
	    t->next = yyvsp[0].a;
	    yyval.a = yyvsp[-2].a;
	}
    break;

  case 47:
#line 392 "./_compparse.y"
    {
	    yyval.a = _dxfMakeArg(NT_CONSTANT);
	    yyval.a->metaType.items = 1;
	    yyval.a->metaType.type = TYPE_INT;
	    yyval.a->metaType.category = CATEGORY_REAL;
	    yyval.a->u.i = yyvsp[0].i;
	}
    break;

  case 48:
#line 400 "./_compparse.y"
    {
	    yyval.a = _dxfMakeArg(NT_CONSTANT);
	    yyval.a->metaType.items = 1;
	    yyval.a->metaType.type = TYPE_FLOAT;
	    yyval.a->metaType.category = CATEGORY_REAL;
	    yyval.a->u.f = yyvsp[0].f;
	}
    break;

  case 49:
#line 408 "./_compparse.y"
    {
	    yyval.a = _dxfMakeArg(NT_CONSTANT);
	    yyval.a->metaType.items = 1;
	    yyval.a->metaType.type = TYPE_DOUBLE;
	    yyval.a->metaType.category = CATEGORY_REAL;
	    yyval.a->u.d = yyvsp[0].d;
	}
    break;

  case 50:
#line 416 "./_compparse.y"
    {
	    yyval.a = _dxfMakeArg(NT_CONSTANT);
	    yyval.a->metaType.items = 1;
	    yyval.a->metaType.type = TYPE_STRING;
	    yyval.a->metaType.category = CATEGORY_REAL;
	    yyval.a->metaType.rank = 1;
	    yyval.a->metaType.shape[0] = strlen(yyvsp[0].s)+1;
	    strcpy(yyval.a->u.s, yyvsp[0].s);
	}
    break;


    }

/* Line 991 of yacc.c.  */
#line 1602 "y.tab.c"

  yyvsp -= yylen;
  yyssp -= yylen;


  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;


  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if YYERROR_VERBOSE
      yyn = yypact[yystate];

      if (YYPACT_NINF < yyn && yyn < YYLAST)
	{
	  YYSIZE_T yysize = 0;
	  int yytype = YYTRANSLATE (yychar);
	  char *yymsg;
	  int yyx, yycount;

	  yycount = 0;
	  /* Start YYX at -YYN if negative to avoid negative indexes in
	     YYCHECK.  */
	  for (yyx = yyn < 0 ? -yyn : 0;
	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
	      yysize += yystrlen (yytname[yyx]) + 15, yycount++;
	  yysize += yystrlen ("syntax error, unexpected ") + 1;
	  yysize += yystrlen (yytname[yytype]);
	  yymsg = (char *) YYSTACK_ALLOC (yysize);
	  if (yymsg != 0)
	    {
	      char *yyp = yystpcpy (yymsg, "syntax error, unexpected ");
	      yyp = yystpcpy (yyp, yytname[yytype]);

	      if (yycount < 5)
		{
		  yycount = 0;
		  for (yyx = yyn < 0 ? -yyn : 0;
		       yyx < (int) (sizeof (yytname) / sizeof (char *));
		       yyx++)
		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
		      {
			const char *yyq = ! yycount ? ", expecting " : " or ";
			yyp = yystpcpy (yyp, yyq);
			yyp = yystpcpy (yyp, yytname[yyx]);
			yycount++;
		      }
		}
	      yyerror (yymsg);
	      YYSTACK_FREE (yymsg);
	    }
	  else
	    yyerror ("syntax error; also virtual memory exhausted");
	}
      else
#endif /* YYERROR_VERBOSE */
	yyerror ("syntax error");
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
	 error, discard it.  */

      /* Return failure if at end of input.  */
      if (yychar == YYEOF)
        {
	  /* Pop the error token.  */
          YYPOPSTACK;
	  /* Pop the rest of the stack.  */
	  while (yyss < yyssp)
	    {
	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
	      yydestruct (yystos[*yyssp], yyvsp);
	      YYPOPSTACK;
	    }
	  YYABORT;
        }

      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
      yydestruct (yytoken, &yylval);
      yychar = YYEMPTY;

    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab2;


/*----------------------------------------------------.
| yyerrlab1 -- error raised explicitly by an action.  |
`----------------------------------------------------*/
yyerrlab1:

  /* Suppress GCC warning that yyerrlab1 is unused when no action
     invokes YYERROR.  */
#if defined (__GNUC_MINOR__) && 2093 <= (__GNUC__ * 1000 + __GNUC_MINOR__)
  __attribute__ ((__unused__))
#endif


  goto yyerrlab2;


/*---------------------------------------------------------------.
| yyerrlab2 -- pop states until the error token can be shifted.  |
`---------------------------------------------------------------*/
yyerrlab2:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (yyn != YYPACT_NINF)
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;

      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
      yydestruct (yystos[yystate], yyvsp);
      yyvsp--;
      yystate = *--yyssp;

      YY_STACK_PRINT (yyss, yyssp);
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  YYDPRINTF ((stderr, "Shifting error token, "));

  *++yyvsp = yylval;


  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#ifndef yyoverflow
/*----------------------------------------------.
| yyoverflowlab -- parser overflow comes here.  |
`----------------------------------------------*/
yyoverflowlab:
  yyerror ("parser stack overflow");
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
  return yyresult;
}


#line 427 "./_compparse.y"


int yyerror(char *s)
{
    if (DXGetError() == ERROR_NONE) {
	DXSetError(ERROR_BAD_PARAMETER, "#12100", s, _dxfcclexerror());
    }
    _dxdparseError++;
    return 0;            /*  Return a value to keep the compiler happy  */
}

